==> apache-druid-28.0.1-src.tar.gz: apache-druid-28.0.1-src/web-console/src/druid-models/coordinator-dynamic-config/coordinator-dynamic-config.mock.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import type { CoordinatorDynamicConfig } from './coordinator-dynamic-config';

export const DEFAULT_COORDINATOR_DYNAMIC_CONFIG: CoordinatorDynamicConfig = {
  millisToWaitBeforeDeleting: 900000,
  mergeBytesLimit: 524288000,
  mergeSegmentsLimit: 100,
  maxSegmentsToMove: 100,
  replicantLifetime: 15,
  replicationThrottleLimit: 500,
  balancerComputeThreads: 1,
  killDataSourceWhitelist: [],
  killTaskSlotRatio: 1,
  maxKillTaskSlots: 2147483647,
  killPendingSegmentsSkipList: [],
  maxSegmentsInNodeLoadingQueue: 500,
  decommissioningNodes: [],
  pauseCoordination: false,
  replicateAfterLoadTimeout: false,
  useRoundRobinSegmentAssignment: true,
  smartSegmentLoading: true,
  debugDimensions: null,
};

==> apache-druid-31.0.2-src.tar.gz: apache-druid-31.0.2-src/web-console/src/druid-models/coordinator-dynamic-config/coordinator-dynamic-config.mock.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import type { CoordinatorDynamicConfig } from './coordinator-dynamic-config';

export const DEFAULT_COORDINATOR_DYNAMIC_CONFIG: CoordinatorDynamicConfig = {
  millisToWaitBeforeDeleting: 900000,
  mergeBytesLimit: 524288000,
  mergeSegmentsLimit: 100,
  maxSegmentsToMove: 100,
  replicantLifetime: 15,
  replicationThrottleLimit: 500,
  balancerComputeThreads: 1,
  killDataSourceWhitelist: [],
  killTaskSlotRatio: 0.1,
  maxKillTaskSlots: 2147483647,
  killPendingSegmentsSkipList: [],
  maxSegmentsInNodeLoadingQueue: 500,
  decommissioningNodes: [],
  pauseCoordination: false,
  replicateAfterLoadTimeout: false,
  useRoundRobinSegmentAssignment: true,
  smartSegmentLoading: true,
  debugDimensions: null,
};
